package cn.com.qmth.scancloud.tools.utils;

import okhttp3.*;

import java.io.File;
import java.util.Map;
import java.util.Map.Entry;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class HttpHelper {

    private static final Logger log = LoggerFactory.getLogger(HttpHelper.class);

    private static final String CONTENT_TYPE = "application/json;charset=UTF-8";

    public static String post(String url, String json) {
        if (log.isDebugEnabled()) {
            log.debug("[POST] {}, params={}", url, json);
        }

        RequestBody requestBody = FormBody.create(json != null ? json : "", MediaType.parse(CONTENT_TYPE));
        Request request = new Request.Builder().post(requestBody).url(url).build();

        try (Response response = HttpClientBuilder.getClient().newCall(request).execute();
                ResponseBody body = response.body();) {
            String bodyStr = body.string();
            if (response.isSuccessful()) {
                return bodyStr;
            }

            log.error("[POST] {}, response code = {}, body = {}", url, response.code(), bodyStr);
        } catch (Exception e) {
            log.error("[POST] {}, error = {}", url, e.getMessage(), e);
        }

        throw new StatusException("接口调用失败！");
    }

    @SuppressWarnings("deprecation")
    public static String post(String url, Map<String, String> params, File file) {

        okhttp3.MultipartBody.Builder multipartBodyBuilder = new MultipartBody.Builder()
                .setType(MultipartBody.ALTERNATIVE);

        if (null != params) {
            for (Entry<String, String> entry : params.entrySet()) {
                multipartBodyBuilder.addFormDataPart(entry.getKey(), entry.getValue());
            }
        }

        MediaType type = MediaType.parse("application/octet-stream");
        RequestBody fileBody = RequestBody.create(type, file);
        multipartBodyBuilder.addFormDataPart("file", file.getName(), fileBody);

        Request request =  new Request.Builder().url(url).post(multipartBodyBuilder.build()).build();

        try (Response response = HttpClientBuilder.getClient().newCall(request).execute();
                ResponseBody body = response.body();) {
            String bodyStr = body.string();
            if (response.isSuccessful()) {
                return bodyStr;
            }

            log.error("[POST] {}, response code = {}, body = {}", url, response.code(), bodyStr);
        } catch (Exception e) {
            log.error("[POST] {}, error = {}", url, e.getMessage(), e);
        }

        throw new StatusException("接口调用失败！");
    }

}
